SystemOrganization addCategory: #'Seaside-Tests-Pharo-Development'!

WAObject subclass: #WAUuidDuplicateContext
	instanceVariableNames: 'seen duplicates'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAUuidDuplicateContext commentStamp: 'pmm 7/23/2011 21:22' prior: 0!
I keep track of seen UUIDs and versions.

Instance Variables:
	seen	<Dictionary<UUID,MCVersionInfo>>
	duplicates	<UUID<Set<MCVersionInfo>>>
		
seen
	all UUIDs seen so far
		
duplicates
	all UUIDs that are used by multiple versions!

!WAUuidDuplicateContext methodsFor: 'public' stamp: 'pmm 7/20/2011 21:18'!
duplicates
	| result |
	result := Dictionary new.
	duplicates keysAndValuesDo: [ :key :value |
		value size > 1 ifTrue: [
			result at: key put: value ] ].
	^ result! !

!WAUuidDuplicateContext methodsFor: 'initialization' stamp: 'pmm 7/23/2011 21:17'!
initialize
	seen := Dictionary new.
	duplicates := Dictionary new! !

!WAUuidDuplicateContext methodsFor: 'public' stamp: 'pmm 7/20/2011 21:30'!
put: aVersionInfo
	| id |
	id := aVersionInfo id.
	(seen includesKey: id)
		ifTrue: [
			| duplicatesForId |
			duplicatesForId := duplicates at: id ifAbsent: [ nil ].
			duplicatesForId isNil ifTrue: [
				| oldValue |
				oldValue := seen at: id.
				"we can get the same ancestor via different paths"
				oldValue name = aVersionInfo name ifFalse: [
					duplicatesForId := self uuidSet.
					duplicates at: id put: duplicatesForId.
					duplicatesForId add: (seen at: id)].
				 ].
			duplicatesForId isNil ifFalse: [
				duplicatesForId add: aVersionInfo ] ]
		ifFalse: [
			seen at: id put: aVersionInfo ]! !

!WAUuidDuplicateContext methodsFor: 'private' stamp: 'pmm 7/20/2011 21:29'!
uuidSet
	^ PluggableSet new
		equalBlock: [ :a :b | a name = b name ];
		hashBlock: [ :a | a name hash ];
		yourself! !

TestCase subclass: #WANoDuplicateUuidsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WANoDuplicateUuidsTest commentStamp: 'pmm 7/23/2011 21:24' prior: 0!
I ensure that there are no two versions with the same UUID. I'm a regression test for a bug in the Pharo/Squeak/Cog VM.!

!WANoDuplicateUuidsTest methodsFor: 'private' stamp: 'pmm 7/23/2011 21:25'!
checkAncestorsOf: aVersionInfo context: aDuplicateContext
	aDuplicateContext put: aVersionInfo.
	aVersionInfo ancestors isEmptyOrNil ifFalse: [
		aVersionInfo ancestors do: [ :each |
			self checkAncestorsOf: each context: aDuplicateContext ] ]! !

!WANoDuplicateUuidsTest methodsFor: 'private' stamp: 'pmm 7/23/2011 21:30'!
checkForDuplicates: aCollectionOfWorkingCopies
	| context |
	context := WAUuidDuplicateContext new.
	aCollectionOfWorkingCopies do: [ :workingCopy |
		 workingCopy ancestors do: [ :each |
			self checkAncestorsOf: each context: context ] ].
	^ context duplicates! !

!WANoDuplicateUuidsTest methodsFor: 'tests' stamp: 'pmm 7/23/2011 21:29'!
testNoDuplicateUuids
	| duplicates workingCopies |
	workingCopies := WADevelopment allPackages collect: [ :each |
		 WADevelopment workingCopyFor: each ].
	duplicates := self checkForDuplicates: workingCopies.
	self assert: duplicates isEmpty! !

TestCase subclass: #WAPackagingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAPackagingTest methodsFor: 'tests' stamp: 'dkh 2/28/2011 15:15'!
testPackagingValidity
	"if this test fails, it is because the current version of the Metacello configuration for Seaside3.0 doesn't match the current GRPackage specifications"

	Smalltalk
		at: #ConfigurationOfSeaside30
		ifPresent:
			[ :cl | 
			| gr me exceptions grease |
			gr := Dictionary new.
			GRPackage packages do: [ :pkg | gr at: pkg name put: pkg ].
			me := Dictionary new.
			cl project currentVersion packages do: [ :pkg | me at: pkg name put: pkg ].	"the following only apply when the system if fully loaded"
			false
				ifTrue:
					[ exceptions := #('Sport-2' 'DynamicBindings' 'Swazoo-2' 'KomHttpServer' 'KomServices').
					me keys do: [ :key | gr at: key ifAbsent: [ self assert: (exceptions includes: key) ] ].
					exceptions := #('Grease-Core' 'Grease-Tests-Core' 'Grease-Pharo-Core' 'Grease-Tests-Pharo-Core').
					gr keys do: [ :key | me at: key ifAbsent: [ self assert: (exceptions includes: key) ] ] ].
			exceptions := #('Seaside-FileSystem' 'Seaside-Swazoo' 'Seaside-Adaptors-Comanche' 'Seaside-Tools-OmniBrowser' 'Seaside-Tests-Slime' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Pharo-Core' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Continuation' 'Seaside-Development' 'Seaside-Tests-Development').
			grease := #('Seaside-Tests-Core' 'Seaside-Tests-Pharo-Continuation' 'Seaside-Core' 'Seaside-Pharo-Core' 'Seaside-Pharo-Flow' 'Seaside-Pharo-Continuation' 'Seaside-Slime' 'Seaside-GemStone-Flow' 'Seaside-GemStone-Continuation' 'Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-Slime' 'Seaside-Tests-Pharo-Email').
			me values
				do:
					[ :pkg | 
					| grPkg |
					grPkg := gr at: pkg name ifAbsent: [  ].
					grPkg notNil
						ifTrue:
							[ | requires dependencies |
							requires := pkg requires.
							dependencies := grPkg dependencies.
							requires size ~= dependencies size
								ifTrue: [ self assert: (exceptions includes: pkg name) ]
								ifFalse:
									[ dependencies
										do:
											[ :grp | 
											(requires includes: grp name)
												ifFalse:
													[ (grease includes: pkg name)
														ifTrue: [ self assert: (grp name beginsWithSubCollection: 'Grease') ]
														ifFalse: [ self assert: false ] ] ] ] ] ] ]! !

TestCase subclass: #WAPharoDebuggerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAPharoDebuggerTest methodsFor: 'private' stamp: 'pmm 9/17/2011 11:52'!
expectedFailures
	"The Pharo debugger API is currently broken.
	When it's fixed this test will pass again and we can add temps to the Pharo walkback again."
	^ #(testNamedTempAt)! !

!WAPharoDebuggerTest methodsFor: 'private' stamp: 'pmm 9/17/2011 11:37'!
signalInterestingError
	GRPlatform current semaphoreClass forMutualExclusion critical: [
		WAError signal: 'foo' ]! !

!WAPharoDebuggerTest methodsFor: 'testing' stamp: 'pmm 9/17/2011 11:52'!
testNamedTempAt
	"This is a test for the Pharo debugger API
	http://code.google.com/p/seaside/issues/detail?id=689"
	| frames |
	frames := OrderedCollection new.
	[ self signalInterestingError ]
		on: WAError
		do: [ :error |
			| context |
			context := error signalerContext.
			[ context isNil ] whileFalse: [
				frames add: context.
				context := context sender ]. ].
	frames do: [ :each |
		1 to: each tempNames size do: [ :i |
			self shouldnt: [ each namedTempAt: i ] raise: Error ] ]! !

TestCase subclass: #WAPharoInspectorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAPharoInspectorTest methodsFor: 'tests' stamp: 'jf 2/15/2010 01:06'!
testInspectorFields
	| values example fields association |
	self assert: Object new inspectorFields isEmpty.
	
	example := WAExampleClass new: 2.
	example first: 'Das Grosse Lernen'.
	example second: 'Die Analekten des Konfuzius'.
	example at: 1 put: 'Mitte und Mass'.
	example at: 2 put: 'Mengzi'.
	
	fields := example inspectorFields.
	self assert: fields size = 4.
	
	association := fields first.
	self assert: association key = #'first'.
	self assert: association value = 'Das Grosse Lernen'.
	
	association := fields second.
	self assert: association key = #'second'.
	self assert: association value = 'Die Analekten des Konfuzius'.
	
	association := fields third.
	self assert: association key = 1.
	self assert: association value = 'Mitte und Mass'.
	
	association := fields fourth.
	self assert: association key = 2.
	self assert: association value = 'Mengzi'.
	
	values := #('Das Grosse Lernen' 'Die Analekten des Konfuzius' 'Mitte und Mass' 'Mengzi').
	
	fields := values inspectorFields.
	self assert: fields size = 4.
	values keysAndValuesDo: [ :index :value |
		association := fields at: index.
		self assert: association key = index.
		self assert: association value = value ].
	
	example := Dictionary new.
	values keysAndValuesDo: [ :index :value |
		example at: index put: value ].
	
	fields := example inspectorFields.
	
	values keysAndValuesDo: [ :index :value |
		self assert: (fields at: index) value = value ]! !

GRObject variableSubclass: #WAExampleClass
	instanceVariableNames: 'first second'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Pharo-Development'!

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
first
	^ first! !

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
first: anObject
	first := anObject! !

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
second
	^ second! !

!WAExampleClass methodsFor: 'accessing' stamp: 'pmm 3/24/2008 17:08'!
second: anObject
	second := anObject! !

!GRPackage class methodsFor: '*seaside-tests-pharo-development' stamp: 'lr 2/17/2010 15:14'!
seasideTestsPharoDevelopment
	^ self new
		name: 'Seaside-Tests-Pharo-Development';
		addDependency: 'Seaside-Pharo-Development';
		addDependency: 'Seaside-Tests-Development';
		url: #seasideUrl;
		yourself! !
